@@ -340,24 +340,38 @@ class S3File:
         return r
 
 
-def get_config():
-    s3_region = get_var("S3_REGION")
-    aws_access_key_id = get_var("ACCESS")
-    aws_secret_access_key = get_var("SECRET")
-    branch = get_var("APP_BRANCH")
-    bucket = get_var("S3_BUCKET")
+@dataclass
+class S3Config:
+    aws_secret_access_key: str
+    aws_access_key_id: str
 
-    return {
+    region: str
+    bucket: str
+
+    profile: Optional[str]
+    endpoint_url: Optional[str]
+
+
+def get_config() -> S3Config:
+    aws_access_key_id = os.environ['AWS_ACCESS_KEY_ID']
+    aws_secret_access_key = os.environ["AWS_SECRET_ACCESS_KEY"]
+    bucket = os.environ["S3_BUCKET"]
+
+    s3_region = os.getenv("S3_REGION", "eu-west-1")
+
+    return S3Config(**{
         "aws_secret_access_key": aws_secret_access_key,
-        "s3_region": s3_region,
+        "region": s3_region,
         "aws_access_key_id": aws_access_key_id,
-        "s3_bucket": "%s-%s" % (bucket, branch.lower()),
-        "profile": os.environ.get("AWS_PROFILE", "")
-    }
+        "bucket": bucket,
+        "profile": os.environ.get("AWS_PROFILE"),
+        "endpoint_url": os.getenv("ENDPOINT_URL")
+    })
 
 
 class S3(object):
     _instace: Optional["S3"] = None
+
     MAX_SESSION_LENGTH = 60 * 60 * 11
 
     def __init__(self, *args, **kwargs):
@@ -375,20 +389,22 @@ class S3(object):
     def invalidate_session(self):
         """ invalidates current session and recreates necessary properties of the class"""
 
-        args = {}
+        args = dict(endpoint_url=self.config.endpoint_url)
+        logger.info("invalidate s3 session")
 
-        if self.config['profile'] == "":
-            access_key_id = self.config['aws_access_key_id']
-            logger.debug(f"start s3 session using access key {access_key_id}")
+        if self.config.profile is None:
+            access_key_id = self.config.aws_access_key_id
+            logger.info(f"start s3 session using access key {access_key_id}")
             session = boto3
             args = dict(
-                region_name=self.config['s3_region'],
+                region_name=self.config.region,
                 aws_access_key_id=access_key_id,
-                aws_secret_access_key=self.config['aws_secret_access_key']
+                aws_secret_access_key=self.config.aws_secret_access_key,
+
             )
         else:
-            profile = self.config['profile']
-            logger.debug(f"start s3 session using profile {profile}")
+            profile = self.config.profile
+            logger.info(f"start s3 session using profile {profile}")
             session = boto3.session.Session(profile_name=profile)
 
         self.s3_client = session.client('s3', **args)
@@ -397,7 +413,6 @@ class S3(object):
 
         # set the start of the new session
         self.start: float = default_timer()
-        print("start is defined...")
 
     def _session_exired(self):
         total_seconds = default_timer() - self.start
@@ -430,29 +445,11 @@ class S3(object):
 
     @property
     def default_bucket(self):
-        return self.config['s3_bucket']
+        return self.config.bucket
 
     @property
     def default_region(self):
-        return self.config['s3_region']
-
-    def __init__(self):
-        self.config = get_config()
-        args = {}
-        if self.config['profile'] == "":
-            session = boto3
-            args = dict(
-                region_name=self.config['s3_region'],
-                aws_access_key_id=self.config['aws_access_key_id'],
-                aws_secret_access_key=self.config['aws_secret_access_key']
-            )
-        else:
-            profile = self.config['profile']
-            session = boto3.session.Session(profile_name=profile)
-
-        self.s3_client = session.client('s3', **args)
-        self.s3 = session.resource('s3', **args)
-        self.transfer = boto3.s3.transfer.S3Transfer(client=self.s3_client)
+        return self.config.region
 
     def copy(self, src_bucket: str, src_key: str, dst_key: str, dst_bucket: Optional[str] = None, check_exists: bool = False) -> bool:
         # returns whether or not the file was copied
